==> refcodes-forwardsecrecy-1.2.5-sources.jar: org/refcodes/forwardsecrecy/CipherVersion.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.forwardsecrecy;

import org.refcodes.mixin.UniversalIdAccessor;

/**
 * A {@link CipherVersion} represents a cipher (used for symmetric encryption
 * respectively decryption) related to a cypher's version (UID). Implementation
 * specific specializations might add attributes to determine whether a
 * {@link CipherVersion} is outdated and must be replaced by a new
 * {@link CipherVersion} or other attributes helpful for housekeeping and
 * management of {@link CipherVersion} instances. The {@link CipherVersion}
 * instances are (indirectly) bound to a namespace.
 */
public interface CipherVersion extends UniversalIdAccessor, Comparable<CipherVersion> {

	/**
	 * Returns the cipher attribute.
	 * 
	 * @return The actual cipher.
	 */
	String getCipher();
}

==> refcodes-forwardsecrecy-3.3.4-sources.jar: org/refcodes/forwardsecrecy/CipherVersion.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.forwardsecrecy;

import org.refcodes.mixin.UniversalIdAccessor;

/**
 * A {@link CipherVersion} represents a cipher (used for symmetric encryption
 * respectively decryption) related to a cypher's version (UID). Implementation
 * specific https://www.metacodes.proizations might add attributes to determine
 * whether a {@link CipherVersion} is outdated and must be replaced by a new
 * {@link CipherVersion} or other attributes helpful for housekeeping and
 * management of {@link CipherVersion} instances. The {@link CipherVersion}
 * instances are (indirectly) bound to a namespace.
 */
public interface CipherVersion extends UniversalIdAccessor, Comparable<CipherVersion> {

	/**
	 * Returns the cipher attribute.
	 * 
	 * @return The actual cipher.
	 */
	String getCipher();
}
